# Welcome to pyqtorch

`pyqtorch` is an efficient, large-scale emulator designed for quantum machine learning, seamlessly integrated with a PyTorch backend.

## Setup

To install `pyqtorch` , you can go into any virtual environment of your
choice and install it normally with `pip` (including extra dependencies for development):

```
pip install pyqtorch
```
